import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Automation, GetAutomationOptions, UpdateAutomation, MigrationUpdateAutomation, MigrationUpdateAutomationResponse, DeleteAutomationOptions, QueryAutomationsOptions, AutomationsQueryBuilder, OverrideApplicationAutomationResponse, ValidateAutomationByIdOptions, ValidateAutomationByIdResponse, ValidateAutomationResponse, GetAutomationActivationStatsOptions, GetAutomationActivationReportsResponse, GetActionsQuotaInfoResponse, GenerateActionInputMappingFromTemplateOptions, GenerateActionInputMappingFromTemplateResponse, AutomationCreatedEnvelope, AutomationDeletedEnvelope, AutomationUpdatedEnvelope, AutomationDeletedWithEntityEnvelope, AutomationUpdatedWithPreviousEntityEnvelope } from './index.typings.mjs';
export { Action, ActionConfigurationError, ActionErrorType, ActionEvent, ActionProviderQuotaInfo, ActionQuotaInfo, ActionValidationError, ActionValidationErrorErrorOneOf, ActionValidationInfo, ActivationReport, ActivationStatus, AdditionalInfo, ApplicationError, Asset, AutomationMetadata, AutomationsQueryResult, BaseEventMetadata, BlockType, BulkActionMetadata, BulkCreateApplicationAutomationRequest, BulkCreateApplicationAutomationResponse, BulkDeleteAutomationsRequest, BulkDeleteAutomationsResponse, CTA, Condition, ConditionBlock, Conditions, CreateAutomationRequest, CreateAutomationResponse, CursorPaging, Cursors, Debounce, Delay, DelayTypeOneOf, DeleteAutomationRequest, DeleteAutomationResponse, DeleteContext, DeleteStatus, DeletedWithEntity, Domain, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, Filter, GenerateActionInputMappingFromTemplateRequest, GenerateApplicationAutomationFromCustomRequest, GenerateApplicationAutomationFromCustomResponse, GetActionsQuotaInfoRequest, GetApplicationAutomationRequest, GetApplicationAutomationResponse, GetAutomationActionSchemaRequest, GetAutomationActionSchemaResponse, GetAutomationActivationReportsRequest, GetAutomationRequest, GetAutomationResponse, IdentificationData, IdentificationDataIdOneOf, ItemMetadata, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, MigrationBulkCreateAutomations, MigrationBulkCreateAutomationsRequest, MigrationBulkCreateAutomationsResponse, MigrationUpdateAutomationRequest, MigrationUpdateMigratedToV3AutomationRequest, MigrationUpdateMigratedToV3AutomationResponse, Namespace, NamespaceChanged, OdeditorAssigned, OdeditorUnassigned, Offset, OffsetValueOneOf, OverrideApplicationAutomationRequest, Paging, PagingMetadata, PagingMetadataV2, PicassoAssigned, PicassoUnassigned, Plan, ProviderConfigurationError, QueryApplicationAutomationsRequest, QueryApplicationAutomationsResponse, QueryAutomationsRequest, QueryAutomationsResponse, QueryV2, QueryV2PagingMethodOneOf, Quota, QuotaInfo, RateLimit, RestoreInfo, Rule, ServiceProvisioned, ServiceRemoved, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SitePurgedExternally, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SiteUrlChanged, SortOrder, Sorting, Source, State, Status, StudioAssigned, StudioUnassigned, SyncApplicationAutomationsRequest, SyncApplicationAutomationsResponse, Trigger, TriggerConfigurationError, TriggerErrorType, TriggerValidationError, TriggerValidationErrorErrorOneOf, TriggerValidationErrorValidationErrorType, Type, Until, UpdateApplicationAutomationConfigurationIdRequest, UpdateApplicationAutomationConfigurationIdResponse, UpdateApplicationAutomationToMigratedFromV1Request, UpdateApplicationAutomationToMigratedFromV1Response, UpdateAutomationRequest, UpdateAutomationResponse, UpdatedAutomationsWithEsb, UpdatedWithPreviousEntity, UpgradeCTA, ValidateAutomationByIdRequest, ValidateAutomationRequest, ValidationErrorType, WebhookIdentityType } from './index.typings.mjs';

type AutomationNonNullablePaths = `name` | `description` | `type` | `status` | `rule.trigger.appId` | `rule.trigger.triggerKey` | `rule.trigger.filters` | `rule.trigger.filters.${number}.fieldKey` | `rule.trigger.filters.${number}.filterExpression` | `rule.trigger.debounce.timeFrameInSeconds` | `rule.trigger.debounce.fieldKey` | `rule.actions` | `rule.actions.${number}.appId` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.actionConfig` | `rule.actions.${number}.delay.for.seconds` | `rule.actions.${number}.delay.for.delayFieldKey` | `rule.actions.${number}.delay.until.dateFieldKey` | `rule.actions.${number}.rateLimit.activations` | `rule.actions.${number}.condition.conditionExpression` | `metadata.hidden` | `metadata.alwaysActive` | `metadata.schedulingModificationDisabled` | `metadata.actionRemovalDisabled` | `metadata.actionConditionsEditingDisabled`;
declare function createAutomation$1(httpClient: HttpClient): CreateAutomationSignature;
interface CreateAutomationSignature {
    /**
     * Creates a new Automation
     * @param - Automation to be created
     * @returns The created Automation
     * @deprecated
     */
    (automation: NonNullablePaths<Automation, `name` | `rule` | `rule.actions` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.appId` | `rule.trigger` | `rule.trigger.appId` | `rule.trigger.triggerKey`>): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
}
declare function getAutomation$1(httpClient: HttpClient): GetAutomationSignature;
interface GetAutomationSignature {
    /**
     * Get a Automation by id
     * @param - Automation ID
     * @returns Automation
     * @deprecated
     */
    (automationId: string, options?: GetAutomationOptions): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
}
declare function updateAutomation$1(httpClient: HttpClient): UpdateAutomationSignature;
interface UpdateAutomationSignature {
    /**
     * Update a Automation, supports partial update
     * Pass the latest `revision` for a successful update
     * @param - Automation ID
     * @returns The updated Automation
     * @deprecated
     */
    (_id: string, automation: NonNullablePaths<UpdateAutomation, `revision`>): Promise<NonNullablePaths<Automation, AutomationNonNullablePaths>>;
}
declare function migrationUpdateAutomation$1(httpClient: HttpClient): MigrationUpdateAutomationSignature;
interface MigrationUpdateAutomationSignature {
    /**
     * @param - Automation ID
     * @deprecated
     */
    (_id: string, automation: MigrationUpdateAutomation): Promise<NonNullablePaths<MigrationUpdateAutomationResponse, {
        [P in AutomationNonNullablePaths]: `automation.${P}`;
    }[AutomationNonNullablePaths]>>;
}
declare function deleteAutomation$1(httpClient: HttpClient): DeleteAutomationSignature;
interface DeleteAutomationSignature {
    /**
     * Delete an Automation
     * @param - Id of the Automation to delete
     * @deprecated
     */
    (automationId: string, options?: DeleteAutomationOptions): Promise<void>;
}
declare function queryAutomations$1(httpClient: HttpClient): QueryAutomationsSignature;
interface QueryAutomationsSignature {
    /**
     * Query Automations using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
     * @deprecated
     */
    (options?: QueryAutomationsOptions): AutomationsQueryBuilder;
}
declare function overrideApplicationAutomation$1(httpClient: HttpClient): OverrideApplicationAutomationSignature;
interface OverrideApplicationAutomationSignature {
    /**
     * Creates a new Automation
     * @param - Application Automation
     * @deprecated
     */
    (automation: NonNullablePaths<Automation, `name` | `rule` | `rule.actions` | `rule.actions.${number}.actionKey` | `rule.actions.${number}.appId` | `rule.trigger` | `rule.trigger.appId` | `rule.trigger.triggerKey`>): Promise<NonNullablePaths<OverrideApplicationAutomationResponse, {
        [P in AutomationNonNullablePaths]: `automation.${P}`;
    }[AutomationNonNullablePaths]>>;
}
declare function validateAutomationById$1(httpClient: HttpClient): ValidateAutomationByIdSignature;
interface ValidateAutomationByIdSignature {
    /**
     * Validate Automation by Id
     * @param - Automation ID
     * @deprecated
     */
    (automationId: string, options?: ValidateAutomationByIdOptions): Promise<NonNullablePaths<ValidateAutomationByIdResponse, `valid` | `triggerValidationErrors` | `triggerValidationErrors.${number}.configurationError.errorType` | `triggerValidationErrors.${number}.providerConfigurationError.message` | `triggerValidationErrors.${number}.providerConfigurationError.title` | `triggerValidationErrors.${number}.errorType` | `actionValidationInfo` | `actionValidationInfo.${number}.appId` | `actionValidationInfo.${number}.actionKey`>>;
}
declare function validateAutomation$1(httpClient: HttpClient): ValidateAutomationSignature;
interface ValidateAutomationSignature {
    /**
     * Validate Automation
     * @param - Automation to validate
     * @deprecated
     */
    (automation: Automation): Promise<NonNullablePaths<ValidateAutomationResponse, `valid` | `triggerValidationErrors` | `triggerValidationErrors.${number}.configurationError.errorType` | `triggerValidationErrors.${number}.providerConfigurationError.message` | `triggerValidationErrors.${number}.providerConfigurationError.title` | `triggerValidationErrors.${number}.errorType` | `actionValidationInfo` | `actionValidationInfo.${number}.appId` | `actionValidationInfo.${number}.actionKey`>>;
}
declare function getAutomationActivationStats$1(httpClient: HttpClient): GetAutomationActivationStatsSignature;
interface GetAutomationActivationStatsSignature {
    /**
     * @param - Automation ID
     * @deprecated
     */
    (automationId: string, options?: GetAutomationActivationStatsOptions): Promise<NonNullablePaths<GetAutomationActivationReportsResponse, `activationReports` | `activationReports.${number}.activationId` | `activationReports.${number}.requestId` | `activationReports.${number}.status`>>;
}
declare function getActionsQuotaInfo$1(httpClient: HttpClient): GetActionsQuotaInfoSignature;
interface GetActionsQuotaInfoSignature {
    /**
     * Get actions quota information
     * @deprecated
     */
    (): Promise<NonNullablePaths<GetActionsQuotaInfoResponse, `actionProviderQuotaInfo` | `actionProviderQuotaInfo.${number}.appId` | `actionProviderQuotaInfo.${number}.actionKey` | `actionProviderQuotaInfo.${number}.actionQuotaInfo.enforced`>>;
}
declare function generateActionInputMappingFromTemplate$1(httpClient: HttpClient): GenerateActionInputMappingFromTemplateSignature;
interface GenerateActionInputMappingFromTemplateSignature {
    /**
     * Generate action input mapping from a template
     * @param - action app id
     * @deprecated
     */
    (appId: string, options: NonNullablePaths<GenerateActionInputMappingFromTemplateOptions, `actionInputMappingTemplate` | `actionKey`>): Promise<GenerateActionInputMappingFromTemplateResponse>;
}
declare const onAutomationCreated$1: EventDefinition<AutomationCreatedEnvelope, "wix.automations.v1.automation_created">;
declare const onAutomationDeleted$1: EventDefinition<AutomationDeletedEnvelope, "wix.automations.v1.automation_deleted">;
declare const onAutomationUpdated$1: EventDefinition<AutomationUpdatedEnvelope, "wix.automations.v1.automation_updated">;
declare const onAutomationDeletedWithEntity$1: EventDefinition<AutomationDeletedWithEntityEnvelope, "wix.automations.v1.automation_deleted_with_entity">;
declare const onAutomationUpdatedWithPreviousEntity$1: EventDefinition<AutomationUpdatedWithPreviousEntityEnvelope, "wix.automations.v1.automation_updated_with_previous_entity">;

declare const createAutomation: MaybeContext<BuildRESTFunction<typeof createAutomation$1> & typeof createAutomation$1>;
declare const getAutomation: MaybeContext<BuildRESTFunction<typeof getAutomation$1> & typeof getAutomation$1>;
declare const updateAutomation: MaybeContext<BuildRESTFunction<typeof updateAutomation$1> & typeof updateAutomation$1>;
declare const migrationUpdateAutomation: MaybeContext<BuildRESTFunction<typeof migrationUpdateAutomation$1> & typeof migrationUpdateAutomation$1>;
declare const deleteAutomation: MaybeContext<BuildRESTFunction<typeof deleteAutomation$1> & typeof deleteAutomation$1>;
declare const queryAutomations: MaybeContext<BuildRESTFunction<typeof queryAutomations$1> & typeof queryAutomations$1>;
declare const overrideApplicationAutomation: MaybeContext<BuildRESTFunction<typeof overrideApplicationAutomation$1> & typeof overrideApplicationAutomation$1>;
declare const validateAutomationById: MaybeContext<BuildRESTFunction<typeof validateAutomationById$1> & typeof validateAutomationById$1>;
declare const validateAutomation: MaybeContext<BuildRESTFunction<typeof validateAutomation$1> & typeof validateAutomation$1>;
declare const getAutomationActivationStats: MaybeContext<BuildRESTFunction<typeof getAutomationActivationStats$1> & typeof getAutomationActivationStats$1>;
declare const getActionsQuotaInfo: MaybeContext<BuildRESTFunction<typeof getActionsQuotaInfo$1> & typeof getActionsQuotaInfo$1>;
declare const generateActionInputMappingFromTemplate: MaybeContext<BuildRESTFunction<typeof generateActionInputMappingFromTemplate$1> & typeof generateActionInputMappingFromTemplate$1>;
/** */
declare const onAutomationCreated: BuildEventDefinition<typeof onAutomationCreated$1>;
/** */
declare const onAutomationDeleted: BuildEventDefinition<typeof onAutomationDeleted$1>;
/** */
declare const onAutomationUpdated: BuildEventDefinition<typeof onAutomationUpdated$1>;
/** */
declare const onAutomationDeletedWithEntity: BuildEventDefinition<typeof onAutomationDeletedWithEntity$1>;
/** */
declare const onAutomationUpdatedWithPreviousEntity: BuildEventDefinition<typeof onAutomationUpdatedWithPreviousEntity$1>;

export { Automation, AutomationCreatedEnvelope, AutomationDeletedEnvelope, AutomationDeletedWithEntityEnvelope, AutomationUpdatedEnvelope, AutomationUpdatedWithPreviousEntityEnvelope, AutomationsQueryBuilder, DeleteAutomationOptions, GenerateActionInputMappingFromTemplateOptions, GenerateActionInputMappingFromTemplateResponse, GetActionsQuotaInfoResponse, GetAutomationActivationReportsResponse, GetAutomationActivationStatsOptions, GetAutomationOptions, MigrationUpdateAutomation, MigrationUpdateAutomationResponse, OverrideApplicationAutomationResponse, QueryAutomationsOptions, UpdateAutomation, ValidateAutomationByIdOptions, ValidateAutomationByIdResponse, ValidateAutomationResponse, createAutomation, deleteAutomation, generateActionInputMappingFromTemplate, getActionsQuotaInfo, getAutomation, getAutomationActivationStats, migrationUpdateAutomation, onAutomationCreated, onAutomationDeleted, onAutomationDeletedWithEntity, onAutomationUpdated, onAutomationUpdatedWithPreviousEntity, overrideApplicationAutomation, queryAutomations, updateAutomation, validateAutomation, validateAutomationById };
