// src/automations-v1-automation-automations-service.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { queryBuilder } from "@wix/sdk-runtime/query-builder";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/automations-v1-automation-automations-service.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressAutomationsServiceAutomationsServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/_api/automations-app",
        destPath: "/api"
      },
      {
        srcPath: "/automations-app",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/automations-app",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_automations_automations-service";
function createAutomation(payload) {
  function __createAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.CreateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createAutomation;
}
function getAutomation(payload) {
  function __getAutomation({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAutomation;
}
function updateAutomation(payload) {
  function __updateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "PATCH",
      methodFqn: "com.wixpress.automations.service.AutomationsService.UpdateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automation.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateAutomation;
}
function migrationUpdateAutomation(payload) {
  function __migrationUpdateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "PATCH",
      methodFqn: "com.wixpress.automations.service.AutomationsService.MigrationUpdateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/migrations/{automation.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __migrationUpdateAutomation;
}
function deleteAutomation(payload) {
  function __deleteAutomation({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "DELETE",
      methodFqn: "com.wixpress.automations.service.AutomationsService.DeleteAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteAutomation;
}
function queryAutomations(payload) {
  function __queryAutomations({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.QueryAutomations",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automations.createdDate" },
            { path: "automations.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryAutomations;
}
function overrideApplicationAutomation(payload) {
  function __overrideApplicationAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.OverrideApplicationAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/override",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __overrideApplicationAutomation;
}
function validateAutomationById(payload) {
  function __validateAutomationById({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.ValidateAutomationById",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}/validate",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __validateAutomationById;
}
function validateAutomation(payload) {
  function __validateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.ValidateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/validate",
        data: serializedData,
        host
      }),
      data: serializedData
    };
    return metadata;
  }
  return __validateAutomation;
}
function getAutomationActivationStats(payload) {
  function __getAutomationActivationStats({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetAutomationActivationStats",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}/activation-stats",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "activationReports.creationDate" },
            { path: "activationReports.updateDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAutomationActivationStats;
}
function getActionsQuotaInfo(payload) {
  function __getActionsQuotaInfo({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetActionsQuotaInfo",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/actions/quota",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            {
              path: "actionProviderQuotaInfo.actionQuotaInfo.quotaInfo.quotas.renewalDate"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getActionsQuotaInfo;
}
function generateActionInputMappingFromTemplate(payload) {
  function __generateActionInputMappingFromTemplate({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GenerateActionInputMappingFromTemplate",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/actions/generate-action-input-mapping-from-template",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __generateActionInputMappingFromTemplate;
}

// src/automations-v1-automation-automations-service.universal.ts
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var Type = /* @__PURE__ */ ((Type2) => {
  Type2["CUSTOM"] = "CUSTOM";
  Type2["APPLICATION"] = "APPLICATION";
  return Type2;
})(Type || {});
var Status = /* @__PURE__ */ ((Status2) => {
  Status2["ACTIVE"] = "ACTIVE";
  Status2["INACTIVE"] = "INACTIVE";
  return Status2;
})(Status || {});
var BlockType = /* @__PURE__ */ ((BlockType2) => {
  BlockType2["UNKNOWN"] = "UNKNOWN";
  BlockType2["OR"] = "OR";
  BlockType2["AND"] = "AND";
  return BlockType2;
})(BlockType || {});
var Domain = /* @__PURE__ */ ((Domain2) => {
  Domain2["USER"] = "USER";
  Domain2["WIX"] = "WIX";
  return Domain2;
})(Domain || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var State = /* @__PURE__ */ ((State2) => {
  State2["UNKNOWN"] = "UNKNOWN";
  State2["ENABLED"] = "ENABLED";
  State2["DISABLED"] = "DISABLED";
  State2["PENDING"] = "PENDING";
  State2["DEMO"] = "DEMO";
  return State2;
})(State || {});
var SiteCreatedContext = /* @__PURE__ */ ((SiteCreatedContext2) => {
  SiteCreatedContext2["OTHER"] = "OTHER";
  SiteCreatedContext2["FROM_TEMPLATE"] = "FROM_TEMPLATE";
  SiteCreatedContext2["DUPLICATE_BY_SITE_TRANSFER"] = "DUPLICATE_BY_SITE_TRANSFER";
  SiteCreatedContext2["DUPLICATE"] = "DUPLICATE";
  SiteCreatedContext2["OLD_SITE_TRANSFER"] = "OLD_SITE_TRANSFER";
  SiteCreatedContext2["FLASH"] = "FLASH";
  return SiteCreatedContext2;
})(SiteCreatedContext || {});
var Namespace = /* @__PURE__ */ ((Namespace2) => {
  Namespace2["UNKNOWN_NAMESPACE"] = "UNKNOWN_NAMESPACE";
  Namespace2["WIX"] = "WIX";
  Namespace2["SHOUT_OUT"] = "SHOUT_OUT";
  Namespace2["ALBUMS"] = "ALBUMS";
  Namespace2["WIX_STORES_TEST_DRIVE"] = "WIX_STORES_TEST_DRIVE";
  Namespace2["HOTELS"] = "HOTELS";
  Namespace2["CLUBS"] = "CLUBS";
  Namespace2["ONBOARDING_DRAFT"] = "ONBOARDING_DRAFT";
  Namespace2["DEV_SITE"] = "DEV_SITE";
  Namespace2["LOGOS"] = "LOGOS";
  Namespace2["VIDEO_MAKER"] = "VIDEO_MAKER";
  Namespace2["PARTNER_DASHBOARD"] = "PARTNER_DASHBOARD";
  Namespace2["DEV_CENTER_COMPANY"] = "DEV_CENTER_COMPANY";
  Namespace2["HTML_DRAFT"] = "HTML_DRAFT";
  Namespace2["SITELESS_BUSINESS"] = "SITELESS_BUSINESS";
  Namespace2["CREATOR_ECONOMY"] = "CREATOR_ECONOMY";
  Namespace2["DASHBOARD_FIRST"] = "DASHBOARD_FIRST";
  Namespace2["ANYWHERE"] = "ANYWHERE";
  Namespace2["HEADLESS"] = "HEADLESS";
  Namespace2["ACCOUNT_MASTER_CMS"] = "ACCOUNT_MASTER_CMS";
  Namespace2["RISE"] = "RISE";
  Namespace2["BRANDED_FIRST"] = "BRANDED_FIRST";
  Namespace2["NOWNIA"] = "NOWNIA";
  Namespace2["UGC_TEMPLATE"] = "UGC_TEMPLATE";
  Namespace2["CODUX"] = "CODUX";
  Namespace2["MEDIA_DESIGN_CREATOR"] = "MEDIA_DESIGN_CREATOR";
  Namespace2["SHARED_BLOG_ENTERPRISE"] = "SHARED_BLOG_ENTERPRISE";
  Namespace2["STANDALONE_FORMS"] = "STANDALONE_FORMS";
  Namespace2["STANDALONE_EVENTS"] = "STANDALONE_EVENTS";
  Namespace2["MIMIR"] = "MIMIR";
  return Namespace2;
})(Namespace || {});
var DeleteStatus = /* @__PURE__ */ ((DeleteStatus2) => {
  DeleteStatus2["UNKNOWN"] = "UNKNOWN";
  DeleteStatus2["TRASH"] = "TRASH";
  DeleteStatus2["DELETED"] = "DELETED";
  DeleteStatus2["PENDING_PURGE"] = "PENDING_PURGE";
  DeleteStatus2["PURGED_EXTERNALLY"] = "PURGED_EXTERNALLY";
  return DeleteStatus2;
})(DeleteStatus || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
var TriggerValidationErrorValidationErrorType = /* @__PURE__ */ ((TriggerValidationErrorValidationErrorType2) => {
  TriggerValidationErrorValidationErrorType2["UNKNOWN_VALIDATION_ERROR_TYPE"] = "UNKNOWN_VALIDATION_ERROR_TYPE";
  TriggerValidationErrorValidationErrorType2["CONFIGURATION_ERROR"] = "CONFIGURATION_ERROR";
  TriggerValidationErrorValidationErrorType2["PROVIDER_ERROR"] = "PROVIDER_ERROR";
  return TriggerValidationErrorValidationErrorType2;
})(TriggerValidationErrorValidationErrorType || {});
var TriggerErrorType = /* @__PURE__ */ ((TriggerErrorType2) => {
  TriggerErrorType2["UNKNOWN_TRIGGER_ERROR_TYPE"] = "UNKNOWN_TRIGGER_ERROR_TYPE";
  TriggerErrorType2["NOT_FOUND"] = "NOT_FOUND";
  TriggerErrorType2["APP_NOT_INSTALLED"] = "APP_NOT_INSTALLED";
  TriggerErrorType2["MODERATION_MISMATCH"] = "MODERATION_MISMATCH";
  TriggerErrorType2["DEPRECATED"] = "DEPRECATED";
  TriggerErrorType2["INVALID_TRIGGER_KEY"] = "INVALID_TRIGGER_KEY";
  TriggerErrorType2["INVALID_FILTER_FIELD_KEY"] = "INVALID_FILTER_FIELD_KEY";
  TriggerErrorType2["INVALID_FILTER_EXPRESSION"] = "INVALID_FILTER_EXPRESSION";
  return TriggerErrorType2;
})(TriggerErrorType || {});
var ValidationErrorType = /* @__PURE__ */ ((ValidationErrorType2) => {
  ValidationErrorType2["UNKNOWN_VALIDATION_ERROR_TYPE"] = "UNKNOWN_VALIDATION_ERROR_TYPE";
  ValidationErrorType2["CONFIGURATION_ERROR"] = "CONFIGURATION_ERROR";
  ValidationErrorType2["PROVIDER_ERROR"] = "PROVIDER_ERROR";
  return ValidationErrorType2;
})(ValidationErrorType || {});
var ActionErrorType = /* @__PURE__ */ ((ActionErrorType2) => {
  ActionErrorType2["UNKNOWN_ACTION_ERROR_TYPE"] = "UNKNOWN_ACTION_ERROR_TYPE";
  ActionErrorType2["NOT_FOUND"] = "NOT_FOUND";
  ActionErrorType2["APP_NOT_INSTALLED"] = "APP_NOT_INSTALLED";
  ActionErrorType2["MODERATION_MISMATCH"] = "MODERATION_MISMATCH";
  ActionErrorType2["DEPRECATED"] = "DEPRECATED";
  ActionErrorType2["INVALID_ACTION_KEY"] = "INVALID_ACTION_KEY";
  ActionErrorType2["INVALID_INPUT_MAPPING"] = "INVALID_INPUT_MAPPING";
  ActionErrorType2["INVALID_OUTPUT_MAPPING"] = "INVALID_OUTPUT_MAPPING";
  ActionErrorType2["INVALID_DELAY"] = "INVALID_DELAY";
  ActionErrorType2["INVALID_RATE_LIMIT"] = "INVALID_RATE_LIMIT";
  ActionErrorType2["INPUT_MAPPING_TYPE_MISMATCH"] = "INPUT_MAPPING_TYPE_MISMATCH";
  ActionErrorType2["INPUT_MAPPING_MISSING_REQUIRED_FIELD"] = "INPUT_MAPPING_MISSING_REQUIRED_FIELD";
  ActionErrorType2["INPUT_MAPPING_SCHEMA_MISMATCH"] = "INPUT_MAPPING_SCHEMA_MISMATCH";
  ActionErrorType2["INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA"] = "INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA";
  return ActionErrorType2;
})(ActionErrorType || {});
var ActivationStatus = /* @__PURE__ */ ((ActivationStatus2) => {
  ActivationStatus2["UNKNOWN_ACTIVATION_REQUEST"] = "UNKNOWN_ACTIVATION_REQUEST";
  ActivationStatus2["IN_PROGRESS"] = "IN_PROGRESS";
  ActivationStatus2["SUCCESS"] = "SUCCESS";
  ActivationStatus2["FAILED"] = "FAILED";
  ActivationStatus2["SCHEDULED"] = "SCHEDULED";
  ActivationStatus2["RETRY"] = "RETRY";
  ActivationStatus2["RESUMED"] = "RESUMED";
  ActivationStatus2["PAUSED"] = "PAUSED";
  return ActivationStatus2;
})(ActivationStatus || {});
async function createAutomation2(automation) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automation
  });
  const reqOpts = createAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.automation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { automation: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["automation"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getAutomation2(automationId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automationId,
    automationType: options?.automationType
  });
  const reqOpts = getAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.automation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          automationId: "$[0]",
          automationType: "$[1].automationType"
        },
        singleArgumentUnchanged: false
      },
      ["automationId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateAutomation2(_id, automation) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automation: { ...automation, id: _id }
  });
  const reqOpts = updateAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.automation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { automation: "$[1]" },
        explicitPathsToArguments: { "automation.id": "$[0]" },
        singleArgumentUnchanged: false
      },
      ["_id", "automation"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function migrationUpdateAutomation2(_id, automation) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automation: { ...automation, id: _id }
  });
  const reqOpts = migrationUpdateAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { automation: "$[1]" },
        explicitPathsToArguments: { "automation.id": "$[0]" },
        singleArgumentUnchanged: false
      },
      ["_id", "automation"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteAutomation2(automationId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automationId,
    revision: options?.revision
  });
  const reqOpts = deleteAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          automationId: "$[0]",
          revision: "$[1].revision"
        },
        singleArgumentUnchanged: false
      },
      ["automationId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
function queryAutomations2(options) {
  const { httpClient, sideEffects } = arguments[1];
  return queryBuilder({
    func: async (payload) => {
      const reqOpts = queryAutomations({
        ...payload,
        ...options ?? {}
      });
      sideEffects?.onSiteCall?.();
      try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return result;
      } catch (err) {
        sideEffects?.onError?.(err);
        throw err;
      }
    },
    requestTransformer: (query) => {
      const args = [query, options];
      return renameKeysFromSDKRequestToRESTRequest({
        ...args?.[1],
        query: args?.[0]
      });
    },
    responseTransformer: ({ data }) => {
      const transformedData = renameKeysFromRESTResponseToSDKResponse(
        transformPaths2(data, [])
      );
      return {
        items: transformedData?.automations,
        pagingMetadata: transformedData?.metadata
      };
    },
    errorTransformer: (err) => {
      const transformedError = sdkTransformError(err, {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { query: "$[0]" },
        singleArgumentUnchanged: false
      });
      throw transformedError;
    },
    pagingMethod: "CURSOR",
    transformationPaths: {}
  });
}
async function overrideApplicationAutomation2(automation) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automation
  });
  const reqOpts = overrideApplicationAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { automation: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["automation"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function validateAutomationById2(automationId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automationId,
    automationType: options?.automationType
  });
  const reqOpts = validateAutomationById(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          automationId: "$[0]",
          automationType: "$[1].automationType"
        },
        singleArgumentUnchanged: false
      },
      ["automationId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function validateAutomation2(automation) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automation
  });
  const reqOpts = validateAutomation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { automation: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["automation"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getAutomationActivationStats2(automationId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    automationId,
    paging: options?.paging,
    fields: options?.fields
  });
  const reqOpts = getAutomationActivationStats(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          automationId: "$[0]",
          paging: "$[1].paging",
          fields: "$[1].fields"
        },
        singleArgumentUnchanged: false
      },
      ["automationId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getActionsQuotaInfo2() {
  const { httpClient, sideEffects } = arguments[0];
  const payload = renameKeysFromSDKRequestToRESTRequest({});
  const reqOpts = getActionsQuotaInfo(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {},
        singleArgumentUnchanged: false
      },
      []
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function generateActionInputMappingFromTemplate2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    appId,
    actionKey: options?.actionKey,
    actionInputMappingTemplate: options?.actionInputMappingTemplate
  });
  const reqOpts = generateActionInputMappingFromTemplate(
    payload
  );
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          appId: "$[0]",
          actionKey: "$[1].actionKey",
          actionInputMappingTemplate: "$[1].actionInputMappingTemplate"
        },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  ActionErrorType,
  ActivationStatus,
  BlockType,
  DeleteStatus,
  Domain,
  Namespace,
  SiteCreatedContext,
  SortOrder,
  State,
  Status,
  TriggerErrorType,
  TriggerValidationErrorValidationErrorType,
  Type,
  ValidationErrorType,
  WebhookIdentityType,
  createAutomation2 as createAutomation,
  deleteAutomation2 as deleteAutomation,
  generateActionInputMappingFromTemplate2 as generateActionInputMappingFromTemplate,
  getActionsQuotaInfo2 as getActionsQuotaInfo,
  getAutomation2 as getAutomation,
  getAutomationActivationStats2 as getAutomationActivationStats,
  migrationUpdateAutomation2 as migrationUpdateAutomation,
  overrideApplicationAutomation2 as overrideApplicationAutomation,
  queryAutomations2 as queryAutomations,
  updateAutomation2 as updateAutomation,
  validateAutomation2 as validateAutomation,
  validateAutomationById2 as validateAutomationById
};
//# sourceMappingURL=index.typings.mjs.map