// src/automations-v1-automation-automations-service.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressAutomationsServiceAutomationsServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/_api/automations-app",
        destPath: "/api"
      },
      {
        srcPath: "/automations-app",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/automations-app",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_automations_automations-service";
function createAutomation(payload) {
  function __createAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.CreateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createAutomation;
}
function getAutomation(payload) {
  function __getAutomation({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAutomation;
}
function updateAutomation(payload) {
  function __updateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "PATCH",
      methodFqn: "com.wixpress.automations.service.AutomationsService.UpdateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automation.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateAutomation;
}
function migrationUpdateAutomation(payload) {
  function __migrationUpdateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "PATCH",
      methodFqn: "com.wixpress.automations.service.AutomationsService.MigrationUpdateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/migrations/{automation.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __migrationUpdateAutomation;
}
function deleteAutomation(payload) {
  function __deleteAutomation({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "DELETE",
      methodFqn: "com.wixpress.automations.service.AutomationsService.DeleteAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteAutomation;
}
function queryAutomations(payload) {
  function __queryAutomations({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.QueryAutomations",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automations.createdDate" },
            { path: "automations.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryAutomations;
}
function overrideApplicationAutomation(payload) {
  function __overrideApplicationAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.OverrideApplicationAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/override",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "automation.createdDate" },
            { path: "automation.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __overrideApplicationAutomation;
}
function validateAutomationById(payload) {
  function __validateAutomationById({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.ValidateAutomationById",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}/validate",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __validateAutomationById;
}
function validateAutomation(payload) {
  function __validateAutomation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "automation.createdDate" },
          { path: "automation.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.ValidateAutomation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/validate",
        data: serializedData,
        host
      }),
      data: serializedData
    };
    return metadata;
  }
  return __validateAutomation;
}
function getAutomationActivationStats(payload) {
  function __getAutomationActivationStats({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetAutomationActivationStats",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/{automationId}/activation-stats",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "activationReports.creationDate" },
            { path: "activationReports.updateDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAutomationActivationStats;
}
function getActionsQuotaInfo(payload) {
  function __getActionsQuotaInfo({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "GET",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GetActionsQuotaInfo",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/actions/quota",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            {
              path: "actionProviderQuotaInfo.actionQuotaInfo.quotaInfo.quotas.renewalDate"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getActionsQuotaInfo;
}
function generateActionInputMappingFromTemplate(payload) {
  function __generateActionInputMappingFromTemplate({ host }) {
    const metadata = {
      entityFqdn: "wix.automations.v1.automation",
      method: "POST",
      methodFqn: "com.wixpress.automations.service.AutomationsService.GenerateActionInputMappingFromTemplate",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAutomationsServiceAutomationsServiceUrl({
        protoPath: "/v1/automations/actions/generate-action-input-mapping-from-template",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __generateActionInputMappingFromTemplate;
}

// src/automations-v1-automation-automations-service.meta.ts
function createAutomation2() {
  const payload = {};
  const getRequestOptions = createAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getAutomation2() {
  const payload = { automationId: ":automationId" };
  const getRequestOptions = getAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/automations/{automationId}",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateAutomation2() {
  const payload = { automation: { id: ":automationId" } };
  const getRequestOptions = updateAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v1/automations/{automation.id}",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function migrationUpdateAutomation2() {
  const payload = { automation: { id: ":automationId" } };
  const getRequestOptions = migrationUpdateAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v1/automations/migrations/{automation.id}",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteAutomation2() {
  const payload = { automationId: ":automationId" };
  const getRequestOptions = deleteAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v1/automations/{automationId}",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryAutomations2() {
  const payload = {};
  const getRequestOptions = queryAutomations(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function overrideApplicationAutomation2() {
  const payload = {};
  const getRequestOptions = overrideApplicationAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations/override",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function validateAutomationById2() {
  const payload = { automationId: ":automationId" };
  const getRequestOptions = validateAutomationById(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations/{automationId}/validate",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function validateAutomation2() {
  const payload = {};
  const getRequestOptions = validateAutomation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations/validate",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getAutomationActivationStats2() {
  const payload = { automationId: ":automationId" };
  const getRequestOptions = getAutomationActivationStats(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/automations/{automationId}/activation-stats",
    pathParams: { automationId: "automationId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getActionsQuotaInfo2() {
  const payload = {};
  const getRequestOptions = getActionsQuotaInfo(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/automations/actions/quota",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function generateActionInputMappingFromTemplate2() {
  const payload = {};
  const getRequestOptions = generateActionInputMappingFromTemplate(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/automations/actions/generate-action-input-mapping-from-template",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  createAutomation2 as createAutomation,
  deleteAutomation2 as deleteAutomation,
  generateActionInputMappingFromTemplate2 as generateActionInputMappingFromTemplate,
  getActionsQuotaInfo2 as getActionsQuotaInfo,
  getAutomation2 as getAutomation,
  getAutomationActivationStats2 as getAutomationActivationStats,
  migrationUpdateAutomation2 as migrationUpdateAutomation,
  overrideApplicationAutomation2 as overrideApplicationAutomation,
  queryAutomations2 as queryAutomations,
  updateAutomation2 as updateAutomation,
  validateAutomation2 as validateAutomation,
  validateAutomationById2 as validateAutomationById
};
//# sourceMappingURL=meta.mjs.map