import { CreateAutomationRequest as CreateAutomationRequest$1, CreateAutomationResponse as CreateAutomationResponse$1, GetAutomationRequest as GetAutomationRequest$1, GetAutomationResponse as GetAutomationResponse$1, UpdateAutomationRequest as UpdateAutomationRequest$1, UpdateAutomationResponse as UpdateAutomationResponse$1, MigrationUpdateAutomationRequest as MigrationUpdateAutomationRequest$1, MigrationUpdateAutomationResponse as MigrationUpdateAutomationResponse$1, DeleteAutomationRequest as DeleteAutomationRequest$1, DeleteAutomationResponse as DeleteAutomationResponse$1, QueryAutomationsRequest as QueryAutomationsRequest$1, QueryAutomationsResponse as QueryAutomationsResponse$1, OverrideApplicationAutomationRequest as OverrideApplicationAutomationRequest$1, OverrideApplicationAutomationResponse as OverrideApplicationAutomationResponse$1, ValidateAutomationByIdRequest as ValidateAutomationByIdRequest$1, ValidateAutomationByIdResponse as ValidateAutomationByIdResponse$1, ValidateAutomationRequest as ValidateAutomationRequest$1, ValidateAutomationResponse as ValidateAutomationResponse$1, GetAutomationActivationReportsRequest as GetAutomationActivationReportsRequest$1, GetAutomationActivationReportsResponse as GetAutomationActivationReportsResponse$1, GetActionsQuotaInfoRequest as GetActionsQuotaInfoRequest$1, GetActionsQuotaInfoResponse as GetActionsQuotaInfoResponse$1, GenerateActionInputMappingFromTemplateRequest as GenerateActionInputMappingFromTemplateRequest$1, GenerateActionInputMappingFromTemplateResponse as GenerateActionInputMappingFromTemplateResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

/** Automation */
interface Automation {
    /**
     * Automation ID
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /** Revision */
    revision?: string | null;
    /**
     * Automation name
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description
     * @maxLength 2000
     */
    description?: string;
    /**
     * Automation Type
     * @readonly
     */
    type?: TypeWithLiterals;
    /** Automation Status */
    status?: StatusWithLiterals;
    /** Rule that contains a trigger and some actions */
    rule?: Rule;
    /**
     * Source Application Automation
     * @readonly
     */
    source?: Source;
    /**
     * Metadata
     * @readonly
     */
    metadata?: AutomationMetadata;
    /**
     * Created date
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Updated date
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * ESB Configuration ID
     * @format GUID
     * @readonly
     */
    esbConfigurationId?: string | null;
    /**
     * Was this automation migrated from v1
     * @readonly
     */
    migratedFromV1?: boolean | null;
    /** @readonly */
    migratedToV3?: boolean | null;
}
declare enum Type {
    CUSTOM = "CUSTOM",
    APPLICATION = "APPLICATION"
}
/** @enumType */
type TypeWithLiterals = Type | 'CUSTOM' | 'APPLICATION';
declare enum Status {
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE"
}
/** @enumType */
type StatusWithLiterals = Status | 'ACTIVE' | 'INACTIVE';
interface Rule {
    /** an event triggered by visitors on a site, or by a site manager (owner & team). */
    trigger?: Trigger;
    /**
     * the actions responding to the trigger happening.
     * ** IMPORTANT NOTE: the order of the actions is important, and will be executed in the order they appear in the list **
     * @minSize 1
     * @maxSize 30
     */
    actions?: Action[];
}
interface Trigger {
    /**
     * the id of the app defining the trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this trigger - human readable action key
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * optional list of filters on schema fields
     * @maxSize 5
     */
    filters?: Filter[];
    /**
     * optional - allows to define a trigger whose following actions will be executed only if the same event for the same resource has not in the last X seconds.
     * for example, if the trigger is "session booked", the resource is a contact and the timeframe is 3600 seconds (contact hasn't booked another session in the last hour),
     * then the actions will be executed only if the same event (session booked for that contact) has not happened in the last hour.
     */
    debounce?: Debounce;
}
interface Filter {
    /**
     * the filter identifier
     * @format GUID
     */
    id?: string | null;
    /**
     * the field key from the schema, for example "formId"
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
    /**
     * filter expression that evaluates to a boolean, for example - {{ contains(["guid1","guid2"];formId) }}
     * @minLength 5
     */
    filterExpression?: string;
}
interface Debounce {
    /**
     * Amount of time in seconds to wait for any additional events to occur before triggering the actions.
     * If no additional events occur within the specified time, the actions will be triggered.
     * If additional events occur within the specified time, the timer will be reset.
     * @min 1
     */
    timeFrameInSeconds?: number;
    /**
     * The field key in the trigger's payload of the entity/event to debounce on
     * For example: if the trigger is "user logged in", the resource is a contact and the resource key is "contactId",
     * Another example: if the trigger is "visitor logged in", the resource is a visitor and the resource key is "visitorId".
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
}
interface Action {
    /**
     * the id of the action for delayed events
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * the id of the app defining the action
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this action - human readable action key - unique per app def id
     * @maxLength 80
     */
    actionKey?: string;
    /**
     * input mapping expression for the action inputs
     * for example:
     * `{  "subject": "Thanks for reaching out!"
     * "message": "Hi {{contact.name.first}}, thanks for contacting our business"
     * }`
     * where the value for "contact.name.first" comes from the trigger's payload
     * @maxLength 20000
     */
    actionConfig?: string;
    /**
     * output mapping expression for the action output
     * for example in get-contact action:
     * `{ "author": "{{$}}" }`
     * This will map the entire entity of contact under `author` namespace
     * @maxLength 3000
     */
    outputActionConfig?: string | null;
    /** Optional delay configuration for the action */
    delay?: Delay;
    /** allows you define an activation policy - like number of activations in a time frame, or limit by some identifier, like contact (e.g. send email to user only at first login) */
    rateLimit?: RateLimit;
    /**
     * allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @deprecated allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @replacedBy conditions
     * @targetRemovalDate 2023-08-01
     */
    condition?: Condition;
    conditions?: Conditions;
    /**
     * allows the user to define a namespace for the action output
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
declare enum BlockType {
    UNKNOWN = "UNKNOWN",
    OR = "OR",
    AND = "AND"
}
/** @enumType */
type BlockTypeWithLiterals = BlockType | 'UNKNOWN' | 'OR' | 'AND';
interface ConditionBlock {
    type?: BlockTypeWithLiterals;
    /**
     * @minSize 1
     * @maxSize 20
     */
    lineExpressions?: string[];
}
interface Offset extends OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** @oneof */
interface OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** calculated as date + delay */
interface Until {
    /** The key of the field in the trigger payload which contains the date to delay until */
    dateFieldKey?: string;
    /** Optional: a delay to add together with the date described in the payload */
    offset?: Offset;
}
interface Delay extends DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
/** @oneof */
interface DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
interface RateLimit {
    /**
     * time frame in minutes
     * @min 1
     */
    timeFrame?: number | null;
    /**
     * number of activations allowed in the given time frame
     * @min 1
     */
    activations?: number;
    /**
     * limit the activation by an entity, for example activate once per contact. example: {{contact.id}}
     * @minLength 1
     * @maxLength 300
     */
    uniqueIdentifierExpression?: string | null;
}
interface Condition {
    /**
     * entity object is deprecated due to the new approach to conditions
     * the condition expression, for example - {{and(gt(price;10);lt(price;100))}}
     * @minLength 1
     * @maxLength 2000
     */
    conditionExpression?: string;
}
interface Conditions {
    /**
     * condition evaluates to `true` if either of the blocks evaluate to `true` (aka OR between all)
     * @minSize 1
     * @maxSize 10
     */
    conditionBlocks?: ConditionBlock[];
}
interface Source {
    /** Automation ID */
    automationId?: string | null;
    /** Application ID */
    appId?: string | null;
    /** Component ID */
    componentId?: string | null;
    /** Version */
    version?: number | null;
}
interface AutomationMetadata {
    /** Is this Automation hidden on a site? */
    hidden?: boolean;
    /** Can this Automation be dismissed (inactivated) on a site? */
    alwaysActive?: boolean;
    /** Is this Automation's scheduling modification is disabled on a site? */
    schedulingModificationDisabled?: boolean;
    /** Is the removal of this Automation's actions disabled? */
    actionRemovalDisabled?: boolean;
    /** Is conditions editing for this Automation allowed on a site? */
    actionConditionsEditingDisabled?: boolean;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about [filtering](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#filters).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about [sorting](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#sorting).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and offset the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface CreateAutomationRequest {
    /** Automation to be created */
    automation: Automation;
}
interface CreateAutomationResponse {
    /** The created Automation */
    automation?: Automation;
}
interface GetAutomationRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface GetAutomationResponse {
    /** Automation */
    automation?: Automation;
}
interface UpdateAutomationRequest {
    /** Automation to be updated, may be partial */
    automation: Automation;
}
interface UpdateAutomationResponse {
    /** The updated Automation */
    automation?: Automation;
}
interface MigrationUpdateAutomationRequest {
    /** Automation to be updated, may be partial */
    automation: Automation;
}
interface MigrationUpdateAutomationResponse {
    /** The updated Automation */
    automation?: Automation;
}
interface DeleteAutomationRequest {
    /**
     * Id of the Automation to delete
     * @format GUID
     */
    automationId: string;
    /** The revision of the Automation */
    revision?: string;
}
interface DeleteAutomationResponse {
}
interface QueryAutomationsRequest {
    /** WQL expression */
    query: QueryV2;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface QueryAutomationsResponse {
    /** List of automations */
    automations?: Automation[];
    /** Paging metadata */
    paging?: PagingMetadataV2;
}
interface OverrideApplicationAutomationRequest {
    /** Application Automation */
    automation: Automation;
}
interface OverrideApplicationAutomationResponse {
    /** Custom Automation */
    automation?: Automation;
}
interface ValidateAutomationByIdRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Automation type */
    automationType?: TypeWithLiterals;
}
interface ValidateAutomationByIdResponse {
    /** is the Automation valid */
    valid?: boolean;
    /**
     * list of validation errors for the automation Trigger
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * list of validation information for the automation Actions
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
}
interface TriggerValidationError extends TriggerValidationErrorErrorOneOf {
    /** trigger configuration error */
    configurationError?: TriggerConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
    /** validation error type */
    errorType?: TriggerValidationErrorValidationErrorTypeWithLiterals;
}
/** @oneof */
interface TriggerValidationErrorErrorOneOf {
    /** trigger configuration error */
    configurationError?: TriggerConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
}
declare enum TriggerValidationErrorValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
/** @enumType */
type TriggerValidationErrorValidationErrorTypeWithLiterals = TriggerValidationErrorValidationErrorType | 'UNKNOWN_VALIDATION_ERROR_TYPE' | 'CONFIGURATION_ERROR' | 'PROVIDER_ERROR';
interface TriggerConfigurationError {
    /** trigger error type */
    errorType?: TriggerErrorTypeWithLiterals;
    /** optional - related filter field key */
    filterFieldKey?: string | null;
}
declare enum TriggerErrorType {
    UNKNOWN_TRIGGER_ERROR_TYPE = "UNKNOWN_TRIGGER_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_TRIGGER_KEY = "INVALID_TRIGGER_KEY",
    INVALID_FILTER_FIELD_KEY = "INVALID_FILTER_FIELD_KEY",
    INVALID_FILTER_EXPRESSION = "INVALID_FILTER_EXPRESSION"
}
/** @enumType */
type TriggerErrorTypeWithLiterals = TriggerErrorType | 'UNKNOWN_TRIGGER_ERROR_TYPE' | 'NOT_FOUND' | 'APP_NOT_INSTALLED' | 'MODERATION_MISMATCH' | 'DEPRECATED' | 'INVALID_TRIGGER_KEY' | 'INVALID_FILTER_FIELD_KEY' | 'INVALID_FILTER_EXPRESSION';
interface ProviderConfigurationError {
    /** Key corresponding to the field in the schema. */
    fieldKey?: string | null;
    /** Error message. */
    message?: string;
    /** Label for a call-to-action button that's displayed with the error. Translated according to the SPI language context. */
    ctaLabel?: string | null;
    /** URL to redirect to when the call-to-action button is clicked. */
    ctaUrl?: string | null;
    /** Title for the error. */
    title?: string;
}
interface ActionValidationInfo {
    /**
     * the id of the action in the automation
     * @format GUID
     */
    actionId?: string | null;
    /**
     * the id of the app defining the action
     * @format GUID
     */
    appId?: string;
    /** human readable identifier of the action per app */
    actionKey?: string;
    /**
     * list of action validation errors
     * @maxSize 100
     */
    validationErrors?: ActionValidationError[];
}
interface ActionValidationError extends ActionValidationErrorErrorOneOf {
    /** action configuration error */
    configurationError?: ActionConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
    /** validation error type */
    errorType?: ValidationErrorTypeWithLiterals;
}
/** @oneof */
interface ActionValidationErrorErrorOneOf {
    /** action configuration error */
    configurationError?: ActionConfigurationError;
    /** provider configuration error */
    providerConfigurationError?: ProviderConfigurationError;
}
declare enum ValidationErrorType {
    UNKNOWN_VALIDATION_ERROR_TYPE = "UNKNOWN_VALIDATION_ERROR_TYPE",
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR",
    PROVIDER_ERROR = "PROVIDER_ERROR"
}
/** @enumType */
type ValidationErrorTypeWithLiterals = ValidationErrorType | 'UNKNOWN_VALIDATION_ERROR_TYPE' | 'CONFIGURATION_ERROR' | 'PROVIDER_ERROR';
interface ActionConfigurationError {
    /** action error type */
    errorType?: ActionErrorTypeWithLiterals;
    /** optional - related field key */
    fieldKey?: string | null;
}
declare enum ActionErrorType {
    UNKNOWN_ACTION_ERROR_TYPE = "UNKNOWN_ACTION_ERROR_TYPE",
    NOT_FOUND = "NOT_FOUND",
    APP_NOT_INSTALLED = "APP_NOT_INSTALLED",
    MODERATION_MISMATCH = "MODERATION_MISMATCH",
    DEPRECATED = "DEPRECATED",
    INVALID_ACTION_KEY = "INVALID_ACTION_KEY",
    INVALID_INPUT_MAPPING = "INVALID_INPUT_MAPPING",
    INVALID_OUTPUT_MAPPING = "INVALID_OUTPUT_MAPPING",
    INVALID_DELAY = "INVALID_DELAY",
    INVALID_RATE_LIMIT = "INVALID_RATE_LIMIT",
    INPUT_MAPPING_TYPE_MISMATCH = "INPUT_MAPPING_TYPE_MISMATCH",
    INPUT_MAPPING_MISSING_REQUIRED_FIELD = "INPUT_MAPPING_MISSING_REQUIRED_FIELD",
    INPUT_MAPPING_SCHEMA_MISMATCH = "INPUT_MAPPING_SCHEMA_MISMATCH",
    INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA = "INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA"
}
/** @enumType */
type ActionErrorTypeWithLiterals = ActionErrorType | 'UNKNOWN_ACTION_ERROR_TYPE' | 'NOT_FOUND' | 'APP_NOT_INSTALLED' | 'MODERATION_MISMATCH' | 'DEPRECATED' | 'INVALID_ACTION_KEY' | 'INVALID_INPUT_MAPPING' | 'INVALID_OUTPUT_MAPPING' | 'INVALID_DELAY' | 'INVALID_RATE_LIMIT' | 'INPUT_MAPPING_TYPE_MISMATCH' | 'INPUT_MAPPING_MISSING_REQUIRED_FIELD' | 'INPUT_MAPPING_SCHEMA_MISMATCH' | 'INPUT_MAPPING_VARIABLE_MISSING_FROM_SCHEMA';
interface ValidateAutomationRequest {
    /** Automation to validate */
    automation: Automation;
}
interface ValidateAutomationResponse {
    /** is the Automation valid */
    valid?: boolean;
    /**
     * list of validation errors for the automation Trigger
     * @maxSize 100
     */
    triggerValidationErrors?: TriggerValidationError[];
    /**
     * list of validation information for the automation Actions
     * @maxSize 100
     */
    actionValidationInfo?: ActionValidationInfo[];
}
interface GetAutomationActivationReportsRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    paging?: Paging;
    /** Fields projection - pass in the field key you want to get back */
    fields?: string[];
}
interface GetAutomationActivationReportsResponse {
    /** Automation activation reports */
    activationReports?: ActivationReport[];
    metadata?: PagingMetadata;
    /** activationStatus -> count */
    stats?: Record<string, number>;
}
interface ActivationReport {
    /** @format GUID */
    activationId?: string;
    requestId?: string;
    status?: ActivationStatusWithLiterals;
    creationDate?: Date | null;
    updateDate?: Date | null;
    /** will be populated when status = FAILED */
    error?: string | null;
}
declare enum ActivationStatus {
    UNKNOWN_ACTIVATION_REQUEST = "UNKNOWN_ACTIVATION_REQUEST",
    IN_PROGRESS = "IN_PROGRESS",
    SUCCESS = "SUCCESS",
    FAILED = "FAILED",
    SCHEDULED = "SCHEDULED",
    RETRY = "RETRY",
    RESUMED = "RESUMED",
    PAUSED = "PAUSED"
}
/** @enumType */
type ActivationStatusWithLiterals = ActivationStatus | 'UNKNOWN_ACTIVATION_REQUEST' | 'IN_PROGRESS' | 'SUCCESS' | 'FAILED' | 'SCHEDULED' | 'RETRY' | 'RESUMED' | 'PAUSED';
interface PagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
}
interface GetActionsQuotaInfoRequest {
}
interface GetActionsQuotaInfoResponse {
    /** list of action quota information */
    actionProviderQuotaInfo?: ActionProviderQuotaInfo[];
}
interface ActionProviderQuotaInfo {
    /**
     * action app id
     * @format GUID
     */
    appId?: string;
    /**
     * the action key
     * @minLength 1
     * @maxLength 80
     */
    actionKey?: string;
    /** the action quota information */
    actionQuotaInfo?: ActionQuotaInfo;
}
interface ActionQuotaInfo {
    /**
     * Whether the quotas for your action are enforced. If you mark this as `true` in the response body,
     * Wix displays the information in the quota object on the site dashboard. If you mark this as `false` for
     * a user, Wix does not display any quota info on the site dashboard for your service.
     */
    enforced?: boolean;
    /**
     * The plans your service provides, together with the quotas enforced by each plan. A site may be enrolled
     * in multiple plans. Plans and quotas can be related as follows:
     *
     * + A single plan has a single quota.
     * + A single plan has multiple quotas.
     * + Multiple plans are associated with multiple quotas.
     *
     * Plans and quotas that are related should be grouped together in a single `quotaInfo`
     * object.
     */
    quotaInfo?: QuotaInfo[];
}
interface QuotaInfo {
    /** List of plans associated with the site making the request. */
    plans?: Plan[];
    /**
     * List of quotas associated with the plans the site is enrolled in.
     * @minSize 1
     */
    quotas?: Quota[];
    /**
     * Details for an upgrade call-to-action button.
     * Displayed in the Wix user’s site dashboard together with the quota details.
     */
    upgradeCta?: UpgradeCTA;
}
interface Plan {
    /** Plan ID defined by the action provider. */
    id?: string;
    /** Plan name to display in the Wix user’s site dashboard. */
    name?: string;
}
interface Quota {
    /**
     * Name of the feature the quota is related to. For example, "Messages sent".
     * @minLength 1
     */
    featureName?: string;
    /**
     * Quota renewal date in [ISO 8601](https://www.iso.org/iso-8601-date-and-time-format.html) format.
     * For example, 10 July 2020 at 15:00 is written as `2020-07-10 15:00:00.000`.
     */
    renewalDate?: Date | null;
    /** The user's current quota usage. */
    currentUsage?: string;
    /** Quota limit data. */
    limit?: string | null;
    /** Additional information about the quota. Displayed as a tooltip in the Wix user’s dashboard. */
    additionalInfo?: AdditionalInfo;
}
interface CTA {
    /**
     * Call-to-action redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * Call-to-action label.
     * @minLength 1
     */
    label?: string;
}
interface AdditionalInfo {
    /**
     * Tooltip content.
     * @minLength 1
     */
    description?: string;
    /** Details for an options call-to-action link that appears in the tooltip. */
    cta?: CTA;
}
interface UpgradeCTA {
    /**
     * CTA button redirect URL.
     * @minLength 1
     */
    url?: string;
    /**
     * CTA button label.
     * @minLength 1
     */
    label?: string;
}
interface GenerateActionInputMappingFromTemplateRequest {
    /** action app id */
    appId: string;
    /** the action key */
    actionKey: string;
    /** action input mapping template the action spi provider will generate input mapping from */
    actionInputMappingTemplate: Record<string, any> | null;
}
interface GenerateActionInputMappingFromTemplateResponse {
    /** generated action input mapping */
    generatedActionInputMapping?: Record<string, any> | null;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createAutomation(): __PublicMethodMetaInfo<'POST', {}, CreateAutomationRequest$1, CreateAutomationRequest, CreateAutomationResponse$1, CreateAutomationResponse>;
declare function getAutomation(): __PublicMethodMetaInfo<'GET', {
    automationId: string;
}, GetAutomationRequest$1, GetAutomationRequest, GetAutomationResponse$1, GetAutomationResponse>;
declare function updateAutomation(): __PublicMethodMetaInfo<'PATCH', {
    automationId: string;
}, UpdateAutomationRequest$1, UpdateAutomationRequest, UpdateAutomationResponse$1, UpdateAutomationResponse>;
declare function migrationUpdateAutomation(): __PublicMethodMetaInfo<'PATCH', {
    automationId: string;
}, MigrationUpdateAutomationRequest$1, MigrationUpdateAutomationRequest, MigrationUpdateAutomationResponse$1, MigrationUpdateAutomationResponse>;
declare function deleteAutomation(): __PublicMethodMetaInfo<'DELETE', {
    automationId: string;
}, DeleteAutomationRequest$1, DeleteAutomationRequest, DeleteAutomationResponse$1, DeleteAutomationResponse>;
declare function queryAutomations(): __PublicMethodMetaInfo<'POST', {}, QueryAutomationsRequest$1, QueryAutomationsRequest, QueryAutomationsResponse$1, QueryAutomationsResponse>;
declare function overrideApplicationAutomation(): __PublicMethodMetaInfo<'POST', {}, OverrideApplicationAutomationRequest$1, OverrideApplicationAutomationRequest, OverrideApplicationAutomationResponse$1, OverrideApplicationAutomationResponse>;
declare function validateAutomationById(): __PublicMethodMetaInfo<'POST', {
    automationId: string;
}, ValidateAutomationByIdRequest$1, ValidateAutomationByIdRequest, ValidateAutomationByIdResponse$1, ValidateAutomationByIdResponse>;
declare function validateAutomation(): __PublicMethodMetaInfo<'POST', {}, ValidateAutomationRequest$1, ValidateAutomationRequest, ValidateAutomationResponse$1, ValidateAutomationResponse>;
declare function getAutomationActivationStats(): __PublicMethodMetaInfo<'GET', {
    automationId: string;
}, GetAutomationActivationReportsRequest$1, GetAutomationActivationReportsRequest, GetAutomationActivationReportsResponse$1, GetAutomationActivationReportsResponse>;
declare function getActionsQuotaInfo(): __PublicMethodMetaInfo<'GET', {}, GetActionsQuotaInfoRequest$1, GetActionsQuotaInfoRequest, GetActionsQuotaInfoResponse$1, GetActionsQuotaInfoResponse>;
declare function generateActionInputMappingFromTemplate(): __PublicMethodMetaInfo<'POST', {}, GenerateActionInputMappingFromTemplateRequest$1, GenerateActionInputMappingFromTemplateRequest, GenerateActionInputMappingFromTemplateResponse$1, GenerateActionInputMappingFromTemplateResponse>;

export { type __PublicMethodMetaInfo, createAutomation, deleteAutomation, generateActionInputMappingFromTemplate, getActionsQuotaInfo, getAutomation, getAutomationActivationStats, migrationUpdateAutomation, overrideApplicationAutomation, queryAutomations, updateAutomation, validateAutomation, validateAutomationById };
